Module registry

Module registry 

Built-in tool registry with definitions for common formatters and linters.

This module provides default configurations for popular tools like ruff, prettier, shellcheck, etc. Users can override these in their configuration.

Structs

ToolRegistry
Registry of built-in tool definitions.

Enums

BuiltinLintMode
How a built-in tool answers the question “is this code block ok?” in a lint slot.
DocsError
Error from splicing the generated docs into docs/code-block-tools.md.
ToolSlot
The configuration list a tool id was written in.

Functions

builtin_lint_mode
Lint behavior of a built-in tool, or None when tool_id is not a built-in.
builtin_tool_formats
Whether a built-in tool has a format invocation, i.e. whether it can fill a format slot. None when tool_id is not a built-in.
builtin_tool_ids
IDs of all built-in (registry) tools, sorted.
render_builtin_tools_table
Render the built-in tools table (the markdown fenced by the doc markers).
splice_builtin_tools_docs
Splice the generated table and the “Built-in tools” count into the docs file text.