check_doc_comment_blocks

Function check_doc_comment_blocks 

pub fn check_doc_comment_blocks(
    content: &str,
    rules: &[Box<dyn Rule>],
    config: &Config,
) -> Vec<LintWarning>
Check all doc comment blocks in a Rust source file and return lint warnings.

Warnings have their line numbers and column numbers remapped to point to the correct location in the original Rust file. Fix suggestions are stripped (fixes are only applied through the fix mode path in the binary crate).

Empty doc comment blocks (only whitespace content) are skipped.