pub struct DocCommentLineInfo {
pub leading_whitespace: String,
pub prefix: String,
}Expand description
Metadata for a single line in a doc comment block.
Fields
leading_whitespace: StringLeading whitespace before the doc comment prefix (e.g. " " for indented code)
prefix: StringThe doc comment prefix as it appeared in source (e.g. "/// ", "///", "///\t")