read_markdown_lossy

Function read_markdown_lossy 

pub fn read_markdown_lossy(path: &Path) -> Result<Option<String>>
Read a Markdown file for indexing, decoding invalid UTF-8 lossily.

Ok(None) means the file is binary and has no Markdown to contribute.