Module fix_coordinator

Module fix_coordinator 

Structs

FixCoordinator
Coordinates rule fixing to minimize the number of passes needed
FixResult
Result of applying fixes iteratively

Functions

config_allows_fix
Whether configuration lets rule_name apply fixes: unfixable does not list it, and fixable, when set, does.