pub struct LinkTargetPolicy { /* private fields */ }Expand description
Run-scoped document paths that filesystem-aware link rules should treat as present even when their content did not come from disk.
Implementations
Sourceimpl LinkTargetPolicy
impl LinkTargetPolicy
Sourcepub fn open_world<I, P>(paths: I) -> Self
pub fn open_world<I, P>(paths: I) -> Self
Supplied documents override disk, while targets outside the supplied set continue to use normal filesystem resolution.
Sourcepub fn closed_world<I, P>(paths: I) -> Self
pub fn closed_world<I, P>(paths: I) -> Self
Only supplied documents are valid relative link targets.
pub fn contains(&self, path: &Path) -> bool
pub fn contains_with_markdown_extension(&self, path: &Path) -> bool
pub fn allow_disk_fallback(&self) -> bool