Module types

Module types 

Structs

BareUrl
Pre-parsed bare URL information (not in links)
BlockquoteInfo
Information about a blockquote line
BrokenLinkInfo
Information about a broken link reported by pulldown-cmark
CharFrequency
Character frequency data for fast content analysis
CodeSpan
Parsed code span information
CommonMarkOrderedList
A borrowed ordered list as grouped by the CommonMark parser.
CommonMarkOrderedListItemsIter
Iterator over the parsed items in one CommonMark ordered list.
CommonMarkOrderedLists
Borrowed collection of CommonMark-grouped ordered lists in source order.
CommonMarkOrderedListsIter
Iterator over CommonMark-grouped ordered lists.
EmphasisSpan
Pre-parsed emphasis span information
FootnoteRef
Parsed footnote reference (e.g., [^1], [^note])
HeadingInfo
Information about a heading
HtmlTag
Pre-parsed HTML tag information
LazyContLine
A lazy continuation line detected by pulldown-cmark.
LineInfo
Pre-computed information about a line
ListBlock
Information about a list block
ListItemInfo
Information about a list item
MathSpan
Parsed math span information (inline $…$ or display $$…$$)
ParsedHeading
A heading recognized in the rendered Markdown document.
ParsedHeadingsIter
Iterator over all headings recognized in the rendered document.
ParsedImage
Parsed image information
ParsedLink
Parsed link information
ParsedListBlock
A borrowed parsed list block and its items.
ParsedListBlockItemsIter
ParsedListBlocks
Borrowed collection of parsed list blocks.
ParsedListBlocksIter
ParsedListItem
A borrowed list item recognized in the parsed document.
ParsedListItemsIter
ReferenceDef
Reference definition [ref]: url "title"
ValidHeading
A valid heading from a filtered iteration
ValidHeadingsIter
Iterator over valid CommonMark headings in a document

Enums

HeadingStyle
Heading style type

Functions

is_horizontal_rule_content
Check if trimmed content matches horizontal rule pattern. Use is_horizontal_rule_line for full CommonMark compliance including indentation check.
is_horizontal_rule_line
Check if a line is a horizontal rule (—, ***, ___) per CommonMark spec. CommonMark rules for thematic breaks (horizontal rules):
is_setext_underline_content
Check if content is a setext underline: a run of = or of -, leading and trailing whitespace allowed, no internal spaces and no mixing of the two markers. = = = is paragraph text, not an underline.