pub struct SuppressedWarning {
pub rule_name: String,
pub line: usize,
pub layer: DisableLayer,
}Expand description
A warning an inline disable comment kept out of a document’s results.
Fields
rule_name: StringCanonical id of the rule that raised the warning, e.g. MD013
line: usize1-indexed line of the warning’s range the rule was found disabled on
layer: DisableLayerThe kind of directive that disabled the rule there