pub struct MD038NoSpaceInCode {
pub enabled: bool,
}Expand description
Rule MD038: No space inside code span markers
See docs/md038.md for full documentation, configuration, and examples.
MD038: Spaces inside code span elements
This rule is triggered when there are spaces inside code span elements.
For example:
` some text`
`some text `
` some text `To fix this issue, remove the leading and trailing spaces within the code span markers:
`some text`Note: Code spans containing backticks (e.g., `backticks` inside) are not flagged
to avoid breaking nested backtick structures used to display backticks in documentation.
Fields
enabled: boolImplementations