pub struct MD049EmphasisStyle { /* private fields */ }Expand description
Rule MD049: Emphasis style
See docs/md049.md for full documentation, configuration, and examples.
This rule is triggered when the style for emphasis is inconsistent:
- Asterisks:
*text* - Underscores:
_text_
This rule is focused on regular emphasis, not strong emphasis.
Implementations
Sourceimpl MD049EmphasisStyle
impl MD049EmphasisStyle
Sourcepub fn new(style: EmphasisStyle) -> Self
pub fn new(style: EmphasisStyle) -> Self
Create a new instance of MD049EmphasisStyle
pub fn from_config_struct(config: MD049Config) -> Self