pub fn parse_blockquote_prefix(line: &str) -> Option<ParsedBlockquotePrefix<'_>>Expand description
Parse a blockquote prefix from a line.
Returns None when the line does not start (after leading indentation) with
a blockquote marker.
pub fn parse_blockquote_prefix(line: &str) -> Option<ParsedBlockquotePrefix<'_>>Parse a blockquote prefix from a line.
Returns None when the line does not start (after leading indentation) with
a blockquote marker.