pub struct ChunkLabel {
pub value: String,
pub source: ChunkLabelSource,
}Expand description
One label found while parsing a chunk header or body.
Fields
value: Stringsource: ChunkLabelSourceTrait Implementations
Sourceimpl Clone for ChunkLabel
impl Clone for ChunkLabel
Sourcefn clone(&self) -> ChunkLabel
fn clone(&self) -> ChunkLabel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChunkLabel
impl Debug for ChunkLabel
Sourceimpl PartialEq for ChunkLabel
impl PartialEq for ChunkLabel
Sourcefn eq(&self, other: &ChunkLabel) -> bool
fn eq(&self, other: &ChunkLabel) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ChunkLabel
impl StructuralPartialEq for ChunkLabel