pub fn is_in_table_cell(
ctx: &LintContext<'_>,
line_num: usize,
_col: usize,
) -> boolExpand description
Check if a position is within a table cell
pub fn is_in_table_cell(
ctx: &LintContext<'_>,
line_num: usize,
_col: usize,
) -> boolCheck if a position is within a table cell