Module text_reflow

Module text_reflow 

Text reflow utilities for MD013

This module implements text wrapping/reflow functionality that preserves Markdown elements like links, emphasis, code spans, etc.

Structs

BlockquoteLineData
A collected blockquote line used for style-preserving reflow.
ParagraphReflow
Information about a reflowed paragraph
ReflowOptions
Options for reflowing text

Enums

BlockquoteContinuationStyle
Style for blockquote continuation lines after reflow.
ReflowLengthMode
Length calculation mode for reflow

Functions

blockquote_continuation_style
Determine the continuation style for a blockquote paragraph from its collected lines.
dominant_blockquote_prefix
Determine the dominant blockquote prefix for a paragraph.
reflow_blockquote_content
Reflow blockquote content lines and apply continuation style.
reflow_line
reflow_markdown
Reflow markdown content preserving structure
reflow_paragraph_at_line
Reflow a single paragraph at the specified line number
reflow_paragraph_at_line_with_mode
Reflow a paragraph at the given line with a specific length mode.
reflow_paragraph_at_line_with_options
Reflow a paragraph at the given line using the provided options.
split_into_sentences
Split text into sentences
split_into_sentences_custom
Split text into sentences with custom abbreviations