normalize_codepoint

Function normalize_codepoint 

pub fn normalize_codepoint(input: &str) -> Result<String, String>
Check a Unicode codepoint token in the format “U+XXXX” or “u+XXXX”, and return a normalized version of it in the format “U+XXXX”. with uppercase letters and no leading/trailing whitespace.