parse_single_char

Function parse_single_char 

pub fn parse_single_char(input: &str) -> Option<char>
Parse a single character from a string, returning Some(char) if the string contains exactly one character, or None if the string is empty or contains more than one character.