Built-in tool registry with definitions for common formatters and linters.
This module provides default configurations for popular tools like ruff, prettier, shellcheck, etc. Users can override these in their configuration.
Structs
- Tool
Registry - Registry of built-in tool definitions.
Enums
- Builtin
Lint Mode - How a built-in tool answers the question “is this code block ok?” in a
lintslot. - Docs
Error - Error from splicing the generated docs into
docs/code-block-tools.md. - Tool
Slot - The configuration list a tool id was written in.
Functions
- builtin_
lint_ mode - Lint behavior of a built-in tool, or
Nonewhentool_idis not a built-in. - builtin_
tool_ formats - Whether a built-in tool has a format invocation, i.e. whether it can fill a
formatslot.Nonewhentool_idis not a built-in. - builtin_
tool_ ids - IDs of all built-in (registry) tools, sorted.
- render_
builtin_ tools_ table - Render the built-in tools table (the markdown fenced by the doc markers).
- splice_
builtin_ tools_ docs - Splice the generated table and the “Built-in tools” count into the docs file text.