pub enum ListItemSpacingStyle {
Consistent,
Loose,
Tight,
}Expand description
Rule MD076: Enforce consistent blank lines between list items
See docs/md076.md for full documentation and examples.
Enforces that the spacing between consecutive list items is consistent within each list: either all gaps have a blank line (loose) or none do (tight).
Configuration
[MD076]
style = "consistent" # "loose", "tight", or "consistent" (default)"consistent"— within each list, all gaps must use the same style (majority wins)"loose"— blank line required between every pair of items"tight"— no blank lines allowed between any items
Variants