pub struct MD077ListContinuationIndent;Expand description
Rule MD077: List continuation content indentation
After a blank line inside a list item, continuation content must be indented to the item’s content column (W+N rule). Under the MkDocs flavor, a minimum of 4 spaces is enforced for ordered list items to satisfy Python-Markdown.