HTML with a markdown attribute detection
Both Python-Markdown’s md_in_html extension (MkDocs) and kramdown (Jekyll)
let an element opt its content into Markdown parsing with a markdown
attribute:
<div class="grid cards" markdown>- Material grid cards<div markdown="1">,<details markdown="block">,<div markdown="span"><p markdown="1">and<h5 markdown="1">- common in Jekyll docs
<div markdown="0"> is kramdown’s opposite and declares the content to be
raw HTML, so it does not open a block here.
Structs
- Markdown
Html Tracker - Track state for markdown HTML block parsing