pub fn parse_single_char(input: &str) -> Option<char>Expand description
Parse a single character from a string, returning Some(char) if the string contains exactly one character,
or None if the string is empty or contains more than one character.